@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -75,19 +75,21 @@ public class HttpServletRequestWrapper implements HttpServletRequest, Parameteri
     private final int serverPort;
     private final boolean isSecure;
     private final String remoteAddress;
+    private final int remotePort;
     private final ConcurrentMap<String, String> additionalParams;
     private final ConcurrentMap<String, String> additionalHeaders;
 
     /**
      * Initializes a new {@link HttpServletRequestWrapper}.
      *
-     * @param requestScheme The scheme of the request: http or https
+     * @param requestScheme The scheme of the request: <code>"http"</code> or <code>"https"</code>
      * @param remoteAddress The remote IP address of the request
+     * @param remotePort The remote port of the request
      * @param serverPort The server port of the request
      * @param httpServletRequest The request (to delegate to)
      * @throws IllegalArgumentException If the port is smaller than 1
      */
-    public HttpServletRequestWrapper(String requestScheme, String remoteAddress, int serverPort, HttpServletRequest httpServletRequest) {
+    public HttpServletRequestWrapper(String requestScheme, String remoteAddress, int remotePort, int serverPort, HttpServletRequest httpServletRequest) {
         if (serverPort < 1) {
             throw new IllegalArgumentException("Port is out of valid range: " + serverPort);
         }
@@ -99,6 +101,7 @@ public class HttpServletRequestWrapper implements HttpServletRequest, Parameteri
             this.isSecure = false;
         }
         this.remoteAddress = remoteAddress;
+        this.remotePort = remotePort;
         this.serverPort = serverPort;
         this.delegate = httpServletRequest;
         this.additionalParams = new ConcurrentHashMap<>(6, 0.9F, 1);
@@ -126,6 +129,7 @@ public class HttpServletRequestWrapper implements HttpServletRequest, Parameteri
         }
         this.serverPort = httpServletRequest.getServerPort();
         this.remoteAddress = httpServletRequest.getRemoteAddr();
+        this.remotePort = httpServletRequest.getRemotePort();
         this.additionalParams = new ConcurrentHashMap<>(6, 0.9F, 1);
         this.additionalHeaders = new ConcurrentHashMap<>(6, 0.9F, 1);
     }
@@ -430,7 +434,7 @@ public class HttpServletRequestWrapper implements HttpServletRequest, Parameteri
 
     @Override
     public int getRemotePort() {
-        return delegate.getRemotePort();
+        return remotePort;
     }
 
     @Override
