@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -226,6 +226,27 @@ public class GrizzlyActivator extends HousekeepingActivator {
                 log.info("Enabled Comet for Grizzly server.");
             }
 
+            // Initialize liveness network listener
+            NetworkListener networkLivenessListener = null;
+            {
+                int livenessPort = grizzlyConfig.getLivenessPort();
+                if (livenessPort > 0) {
+                    networkLivenessListener = new NetworkListener("liveness-listener", grizzlyConfig.getHttpHost(), livenessPort);
+
+                    // Set the maximum body/header size as well as HTTP session manager
+                    networkLivenessListener.setMaxFormPostSize(1);
+                    networkLivenessListener.setMaxBufferedPostSize(1);
+                    networkLivenessListener.setMaxHttpHeaderSize(grizzlyConfig.getMaxHttpHeaderSize());
+
+                    // Set the transport
+                    networkLivenessListener.setTransport(buildTcpNioTransport(grizzlyConfig, threadPool));
+
+                    // Add HTTP network listener to Grizzly server
+                    grizzly.addListener(networkLivenessListener);
+                    log.info("Prepared Grizzly liveness network listener on host: {} and port: {}, but not yet started...", grizzlyConfig.getHttpHost(), Integer.valueOf(livenessPort));
+                }
+            }
+
             // Initialize HTTP network listener
             {
                 NetworkListener networkListener = new NetworkListener("http-listener", grizzlyConfig.getHttpHost(), grizzlyConfig.getHttpPort());
@@ -237,7 +258,7 @@ public class GrizzlyActivator extends HousekeepingActivator {
                 networkListener.setSessionManager(sessionManager);
 
                 // Set the transport
-                networkListener.setTransport(buildTcpNioTransport(configurationService, threadPool));
+                networkListener.setTransport(buildTcpNioTransport(grizzlyConfig, threadPool));
 
                 // Web Socket and Comet
                 if (websocketsEnabled) {
@@ -268,7 +289,7 @@ public class GrizzlyActivator extends HousekeepingActivator {
                 networkSslListener.setSecure(true);
 
                 // Set the transport
-                networkSslListener.setTransport(buildTcpNioTransport(configurationService, threadPool));
+                networkSslListener.setTransport(buildTcpNioTransport(grizzlyConfig, threadPool));
 
                 // Web Socket and Comet
                 if (websocketsEnabled) {
@@ -283,8 +304,16 @@ public class GrizzlyActivator extends HousekeepingActivator {
                 log.info("Prepared Grizzly HTTPS network listener on host: {} and port: {}, but not yet started...", grizzlyConfig.getHttpHost(), Integer.valueOf(grizzlyConfig.getHttpsPort()));
             }
 
-            // Start Grizzly server
+            // Start Grizzly server / Liveness end-point
             grizzly.start();
+            if (networkLivenessListener != null) {
+                try {
+                    networkLivenessListener.start();
+                    log.info("Started Grizzly liveness network listener on host: {} and port: {}", grizzlyConfig.getHttpHost(), Integer.valueOf(grizzlyConfig.getLivenessPort()));
+                } catch (Exception e) {
+                    log.error("Failed to start Grizzly liveness network listener on host: {} and port: {}", grizzlyConfig.getHttpHost(), Integer.valueOf(grizzlyConfig.getLivenessPort()), e);
+                }
+            }
 
             // The HttpService factory
             HttpServiceFactory httpServiceFactory;
@@ -340,21 +369,21 @@ public class GrizzlyActivator extends HousekeepingActivator {
     /**
      * Builds a TCPNIOTransport using {c.o}.threadpool
      *
-     * @param configurationService The configuration service to use to read settings for TCP NIO connections
+     * @param grizzlyConfig The configuration to use to set settings for TCP NIO connections
      * @param threadPool The thread pool to use
      * @return The configured <code>TCPNIOTransport</code> instance
      * @throws OXException If the transport cannot be build
      */
-    private TCPNIOTransport buildTcpNioTransport(ConfigurationService configurationService, ThreadPoolService threadPool) throws OXException {
-        if (getService(ThreadPoolService.class) == null) {
+    private TCPNIOTransport buildTcpNioTransport(GrizzlyConfig grizzlyConfig, ThreadPoolService threadPool) throws OXException {
+        if (threadPool == null) {
             throw GrizzlyExceptionCode.NEEDED_SERVICE_MISSING.create(ThreadPoolService.class.getSimpleName());
         }
 
         // Determine settings for TCP NIO connections
-        boolean keepAlive = configurationService.getBoolProperty("com.openexchange.http.grizzly.keepAlive", true);
-        boolean tcpNoDelay = configurationService.getBoolProperty("com.openexchange.http.grizzly.tcpNoDelay", true);
-        int readTimeoutMillis = configurationService.getIntProperty("com.openexchange.http.grizzly.readTimeoutMillis", org.glassfish.grizzly.Transport.DEFAULT_READ_TIMEOUT * 1000);
-        int writeTimeoutMillis = configurationService.getIntProperty("com.openexchange.http.grizzly.writeTimeoutMillis", org.glassfish.grizzly.Transport.DEFAULT_WRITE_TIMEOUT * 1000);
+        boolean keepAlive = grizzlyConfig.isKeepAlive();
+        boolean tcpNoDelay = grizzlyConfig.isTcpNoDelay();
+        int readTimeoutMillis = grizzlyConfig.getReadTimeoutMillis();
+        int writeTimeoutMillis = grizzlyConfig.getWriteTimeoutMillis();
 
         // Build up the TCPNIOTransport to use
         TCPNIOTransportBuilder builder = TCPNIOTransportBuilder.newInstance();
