@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -58,7 +58,7 @@
  * only if the new code is made subject to such option by the copyright
  * holder.
  *
- * Portions Copyright 2016-2020 OX Software GmbH, licensed under GPL Version 2.
+ * Portions Copyright 2016-2020 Open-Xchange GmbH, licensed under GPL Version 2.
  */
 
 package com.openexchange.http.grizzly.service.http;
@@ -209,14 +209,7 @@ public class OSGiMainHandler extends HttpHandler implements OSGiHandler {
                     processingLock.lock();
                     try {
                         updateMappingInfo(request, alias, originalAlias);
-
-                        OXThreadMarker threadMarker = threadMarker();
-                        threadMarker.setHttpRequestProcessing(true);
-                        try {
-                            httpHandler.service(request, response);
-                        } finally {
-                            threadMarker.setHttpRequestProcessing(false);
-                        }
+                        doHttpService(request, response, httpHandler);
                     } catch (Throwable t) {
                         ExceptionUtils.handleThrowable(t);
                         StringBuilder logBuilder = new StringBuilder(128).append("Error processing request:\n");
@@ -267,14 +260,7 @@ public class OSGiMainHandler extends HttpHandler implements OSGiHandler {
                 processingLock.lock();
                 try {
                     updateMappingInfo(request, alias, originalAlias);
-
-                    OXThreadMarker threadMarker = threadMarker();
-                    threadMarker.setHttpRequestProcessing(true);
-                    try {
-                        httpHandler.service(request, response);
-                    } finally {
-                        threadMarker.setHttpRequestProcessing(false);
-                    }
+                    doHttpService(request, response, httpHandler);
                 } catch (Throwable t) {
                     ExceptionUtils.handleThrowable(t);
                     StringBuilder logBuilder = new StringBuilder(128).append("Error processing request:\n");
@@ -303,6 +289,22 @@ public class OSGiMainHandler extends HttpHandler implements OSGiHandler {
         }
     }
 
+    private static void doHttpService(Request request, Response response, HttpHandler httpHandler) throws Exception {
+        Thread t = Thread.currentThread();
+        if (!(t instanceof OXThreadMarker)) {
+            httpHandler.service(request, response);
+            return;
+        }
+
+        OXThreadMarker threadMarker = (OXThreadMarker) t;
+        threadMarker.setHttpRequestProcessing(true);
+        try {
+            httpHandler.service(request, response);
+        } finally {
+            threadMarker.setHttpRequestProcessing(false);
+        }
+    }
+
     /**
      * Appends request information.
      *
@@ -768,24 +770,4 @@ public class OSGiMainHandler extends HttpHandler implements OSGiHandler {
 
     }
 
-    // -----------------------------------------------------------------------------------------
-
-    private static final OXThreadMarker DUMMY = new OXThreadMarker() {
-
-        @Override
-        public void setHttpRequestProcessing(boolean httpProcessing) {
-            // Nothing
-        }
-
-        @Override
-        public boolean isHttpRequestProcessing() {
-            return false;
-        }
-    };
-
-    private static OXThreadMarker threadMarker() {
-        Thread t = Thread.currentThread();
-        return t instanceof OXThreadMarker ? (OXThreadMarker) t : DUMMY;
-    }
-
 }
