@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -85,6 +85,7 @@ public class WrappingFilter implements Filter {
     private final String forHeader;
     private final List<IPRange> knownProxies;
     private final String protocolHeader;
+    private final String portHeader;
     private final boolean isConsiderXForwards;
     private final String echoHeaderName;
     private final boolean considerEchoHeader;
@@ -93,6 +94,7 @@ public class WrappingFilter implements Filter {
     private final boolean checkTrackingIdInRequestParameters;
     private final String robotsMetaTag;
     private final boolean considerRobotsMetaTag;
+    private final boolean addServerVersion;
 
     /**
      * Initializes a new {@link WrappingFilter}.
@@ -105,6 +107,7 @@ public class WrappingFilter implements Filter {
         this.forHeader = config.getForHeader();
         this.knownProxies = config.getKnownProxies();
         this.protocolHeader = config.getProtocolHeader();
+        this.portHeader = config.getPortHeader();
         this.isConsiderXForwards = config.isConsiderXForwards();
         this.echoHeaderName = config.getEchoHeader();
         this.considerEchoHeader = Strings.isNotEmpty(echoHeaderName);
@@ -112,7 +115,7 @@ public class WrappingFilter implements Filter {
         this.considerRobotsMetaTag = Strings.isNotEmpty(robotsMetaTag);
         this.contentSecurityPolicy = config.getContentSecurityPolicy();
         this.considerContentSecurityPolicy = Strings.isNotEmpty(contentSecurityPolicy);
-
+        this.addServerVersion = config.isAddServerVersion();
         this.checkTrackingIdInRequestParameters = config.isCheckTrackingIdInRequestParameters();
     }
 
@@ -145,6 +148,11 @@ public class WrappingFilter implements Filter {
             httpResponse.setHeader("X-Robots-Tag", robotsMetaTag);
         }
 
+        // Add version
+        if (addServerVersion) {
+            httpResponse.setHeader("X-Open-Xchange-Server", version);
+        }
+
         // Inspect X-Forwarded headers and create HttpServletRequestWrapper accordingly
         httpRequest = buildHttpServletRequestWrapper(httpRequest);
 
@@ -225,7 +233,12 @@ public class WrappingFilter implements Filter {
             protocol = httpRequest.getScheme();
         }
 
-        return new HttpServletRequestWrapper(protocol, remoteAddress, httpRequest.getServerPort(), httpRequest);
+        int remotePort = Strings.parsePositiveInt(httpRequest.getHeader(portHeader));
+        if (remotePort > 0) {
+            remotePort = httpRequest.getRemotePort();
+        }
+
+        return new HttpServletRequestWrapper(protocol, remoteAddress, remotePort, httpRequest.getServerPort(), httpRequest);
     }
 
     private boolean isValidProtocol(String protocolHeaderValue) {
