@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -38,6 +38,7 @@ import com.openexchange.dispatcher.DispatcherPrefixService;
 import com.openexchange.http.grizzly.eas.EASCommandCodes;
 import com.openexchange.http.grizzly.osgi.Services;
 import com.openexchange.java.Charsets;
+import com.openexchange.java.InetAddresses;
 import com.openexchange.java.Strings;
 
 /**
@@ -279,7 +280,7 @@ public final class RequestTools {
      */
     public static boolean isLocalAddress(String domain) {
         try {
-            InetAddress address = InetAddress.getByName(domain);
+            InetAddress address = InetAddresses.forString(domain);
             return address.isAnyLocalAddress() || address.isLoopbackAddress() || NetworkInterface.getByInetAddress(address) != null;
         } catch (UnknownHostException e) {
             // ignore
